<# PowerCLI Cookbook - Chapter 2 Code #> 

<# Connect to vCenter Server #>
Connect-VIServer vcentersrv.domain.local

<# List current Datacenters defined #>
Get-Datacenter

<# List root folder #>
Get-Folder -NoRecursion

<# Combine cmdlets to create a new Datacenter at the root folder #>
New-Datacenter -Name "Primary" -Location (Get-Folder -NoRecursion)

<# Create a new DRS cluster #>
New-Cluster -Location (Get-Datacenter "Primary") -Name BigCluster -HAEnabled -DRSEnabled -DRSAutomationLevel FullyAutomated

<# Add Host into a DRS Cluster #>
#Get-VMHost esxsrv1.domain.local | Move-VM -Location (Get-Cluster -Name "BigCluster")
Add-VMHost -Name esxsrv1.domain.local -Location (Get-Cluster -Name "BigCluster") -Force:$true

<# Change cluster settings #>
Set-Cluster -Cluster "BigCluster" -HAEnable $false
Set-Cluster -Cluster "BigCluster" -HAEnable $true
Set-Cluster -Cluster "BigCluster" -HAadmissionControlEnabled $true -HAFailoverLevel 1
Set-Cluster -Cluster "BigCluster" -HAadmissionControlEnabled $false <# Set this for future recipes in the book, if you have only one ESXi hosts #>
Set-Cluster -Cluster "BigCluster" -HAIsolationResponse PowerOff -HaRestartPriority Medium
Set-Cluster -Cluster "BigCluster" -DrsAutomationLevel Manual -Confirm:$false
Set-Cluster -Cluster "BigCluster" -DrsAutomationLevel FullyAutomated -Confirm:$false 
$domaincontrollers = Get-VM -Name "DC*"
New-DrsRule -Name "Separate DCs" -Cluster "BigCluster" -Enabled $true -KeepTogether $false -VM $domaincontrollers 
Get-Cluster "BigCluster" | Select Name, EVCMode
Set-Cluster -Cluster "BigCluster" -EVCMode 'intel-penryn'	

<# Working with Resource Pools #>
Get-ResourcePool -Name "Resources" -Location (Get-Cluster -Name "BigCluster")
New-ResourcePool -Name "Production" -Location (Get-ResourcePool -Name "Resources" -Location (Get-Cluster -Name "BigCluster") ) -CPUSharesLevel high -MemSharesLevel high -CpuExpandableReservation $true -MemExpandableReservation $true
New-ResourcePool -Name "Production" -Location "BigCluster" -CPUSharesLevel high -MemSharesLevel high -CpuExpandableReservation $true -MemExpandableReservation $true
New-ResourcePool -Name "Development" -Location "BigCluster" -CPUSharesLevel low -MemSharesLevel low -CpuExpandableReservation $true -MemExpandableReservation $true
Move-VM -Name vCenterSrv -Location (Get-ResourcePool "Production")
Set-ResourcePool -ResourcePool (Get-ResourcePool Production) -CpuSharesLevel Custom -NumCpuShare 8000

<# Obtain the root folder of a Datacenter #> 
Get-Datacenter -Name "Primary" | Get-Folder -name "vm"

<# Create new folder in a datacenter #>
New-Folder -Name "Infrastructure" -Location (Get-Datacenter -Name "Primary" | Get-Folder -name "vm")
New-Folder -Name "App Servers" -Location (Get-Datacenter -Name "Primary" | Get-Folder -name "vm")
New-Folder -Name "Domain Controllers" -Location (Get-Datacenter -Name "Primary" | Get-Folder -name "Infrastructure")
New-Folder -Name "VMware" -Location (Get-Datacenter -Name "Primary" | Get-Folder -name "Infrastructure")
New-Folder -Name "Standard vSwitches" -Location (Get-Datacenter -Name "Primary" | Get-Folder -Name "network")
New-Folder -Name "NFS" -Location (Get-Datacenter -Name "Primary" | Get-Folder -Name "datastore")
New-Folder -Name "iSCSI" -Location (Get-Datacenter -Name "Primary" | Get-Folder -Name "datastore")
New-Folder -Name "Finance" -Location (Get-Datacenter -Name "Primary" | Get-Folder -Name "host")
New-Folder -Name "IT" -Location (Get-Datacenter -Name "Primary" | Get-Folder -Name "host")

<# Relocate Objects into Folders #>
Move-VM -VM "vCenterSrv" -Location (Get-Folder -Name "VMware")
Move-Cluster -Cluster "BigCluster" -Location (Get-Folder -Name "IT")
Move-Datastore -Datastore "NFSDatastore1" -Destination (Get-Folder -Name "NFS") 
Move-Datastore -Datastore "iSCSIDatastore1" -Destination (Get-Folder -Name "iSCSI") 

<# Working with Permissions on Objects #>
Get-VIRole | Select Name, Description
New-VIPermission -Entity (Get-Datacenter -Name "Primary") -Principal "DOMAIN\IT Admins" -Role Admin
New-VIPermission -Entity (Get-Folder "Finance") -Principal "DOMAIN\Finance Developers" -Role VirtualMachineUser
New-VIPermission -Entity (Get-Datacenter "Primary") -Principal "DOMAIN\reports" -Role ReadOnly
Get-VIRole -Name readonly | Select Name, PrivlegeList
Get-VIPrivilege -Name *larm*
New-VIRole -Name "IT Monitoring" -Privilege "Anonymous","View", "Read","Acknowledge alarm"
New-VIPermission -Entity (Get-Datacenter -Name "Primary") -Principal "DOMAIN\IT Monitoring Group" -Role "IT Monitoring"
