<# PowerCLI Cookbook - Chapter 3 Code #>

<# Deploying the first virtual machine #>
New-VM -Name WinVM1 -ResourcePool "Production" -NumCPU 2 -MemoryGB 4 -DiskGB 60 -NetworkName "Infrastructure Network" -CD -GuestID "windows7server64Guest"

<# Cloning a virtual machine to template #>
Get-VM WinVM1 | New-VM -Name "WinTemplate" -DiskStorageFormat Thin -ResourcePool Production 
Set-VM -VM "WinTemplate" -ToTemplate -Confirm:$false

<# Deploying many new virtual machines from template #>
New-VM -Template "WinTemplate" -Name "NewWinVM" -ResourcePool "Production" -DiskStorageFormat Thick -Location "App Servers"

<# Importing a virtual appliance from OVA #>
Import-vApp -Source C:\va\SliTaz4.0\SliTaz4.0.ovf -Name "SliTaz4.0" -VMHost esxsrv1.domain.local
Start-VM -VM "SliTaz4.0"

<# Hot add virtual hardware to an existing virtual machine #>
$vmview = Get-VM WinVM1 | Get-View
$ConfigSpec = New-Object VMware.VIM.VirtualMachineConfigSpec
$options = New-Object VMware.VIM.optionvalue
$options.Key = "mem.hotadd"
$options.Value = "true"
$ConfigSpec.extraconfig += $options
$vmview.ReconfigVM($ConfigSpec)
$options.Key = "vcpu.hotadd"
$options.Value = "true"
$ConfigSpec.extraconfig += $options
$vmview.ReconfigVM($ConfigSpec)
Start-VM -VM WinVM1
Set-VM -VM WinVM1 -MemoryGB 2
Get-VM WinVM1 | New-HardDisk -CapacityGB 20 

<# Enabling and disabling Fault Tolerance on a virtual machine #>
$vm = Get-VM "WinVM1"
$vm.ExtensionData.QueryFaultToleranceCompatibility()
$vm.ExtensionData.CreateSecondaryVM($null)
Start-VM -VM "WinVM1"
$vm.ExtensionData.TurnOffFaultToleranceForVM()

<# Increasing the disk space in a virtual machine #>
Get-VM "WinVM1" | Get-HardDisk | Where {$_.CapacityGB -eq 60} | Set-HardDisk -CapacityGB 80 -Confirm:$false
Get-VM "WinVM1" | Get-HardDisk

<# Upgrading virtual hardware version of a virtual machine  #>
New-VM -VM SliTaz4.0 -Name SliTazTest -ResourcePool Production
Get-VM SliTazTest | Select Name, Version
Get-VM SliTazTest | New-Snapshot -Name "Before Virtual Hardware Upgrade" 
Set-VM -VM SliTazTest -Version v8
Start-VM -VM SliTazTest
Export-Console SliTazTest

<# Locating and reloading inaccessible or invalid virtual machines #>
$vmview = Get-View -ViewType VirtualMachine
$vmview | Where {$_.Runtime.ConnectionState -eq "inaccessible" -or $_.Runtime.ConnectionState -eq "invalid"} # | ($_.Reload())

<# Setting VMware Tool settings from PowerCLI #>
$vmview = Get-View -VIObject (Get-VM WinVM1)
$ConfigSpec = New-Object VMware.Vim.VirtualMachineConfigSpec
$ConfigSpec.ChangeVersion = $vmview.Config.ChangeVersion
$ConfigSpec.tools = New-Object VMware.Vim.ToolsConfigInfo
$ConfigSpec.tools.toolsUpgradePolicy = "upgradeAtPowerCycle"
$ConfigSpec.tools.syncTimeWithHost = $true
$vmview.ReconfigVM($ConfigSpec)

<# Creating basic reports of VM properties from VMware Tools and PowerCLI #>
<# Quick reports from PowerCLI objects #>
$InfraVMs = Get-VM -Location "Infrastructure"
$InfraVMs | Select Name, NumCPU, MemoryGB, Description, Host, PowerState | Export-CSV -Path infravms.csv
$head = '<style>
body { font-family: Helvetica;
       font-size: 12pt; }
td, th { border: 1px solid black;  }
th { color:white;
     background-color:black; }
table, tr, td, th { padding: 4px; margin: 0px }
</style>'
$InfraVMs | Select Name, NumCPU, MemoryGB, Description, Host, PowerState | ConvertTo-HTML -head $head | Out-File infravms.html

<# Filesystem free space monitoring, see CheckFreeSpace.ps1 #>
