<# PowerCLI Cookbook - Chapter 4 Code #>

<# Working with Datastores #>
Move-VM -VM TTYLinux1 -Datastore iSCSIDatastore2
Get-VM -Datastore iSCSIDatastore1
Get-VM -Datastore iSCSIDatastore1 | Move-VM -Datastore iSCSIDatastore2
Get-VM -Name TTYLinux* -Datastore iSCSIDatastore1 | Move-VM -Datastore iSCSIDatastore2

<# Working with Individual Hard Disk Files #>
Get-VM | Get-HardDisk
Get-VM | Get-HardDisk | Get-Member
Get-VM | Get-HardDisk -DiskType "RawPhysical","RawVirtual"
Get-VM | Get-HardDisks
Get-VM | Get-HardDisks | Get-Member
Get-VM | Get-HardDisk | Where {$_.StorageFormat -like "Thin"}
Get-VM | Get-HardDisk | Where {$_.StorageFormat -like "Thin"}
Get-VM | Get-Member
Get-VM | Where {$_.HardDisks.StorageFormat -like "Thin"}
Get-VM | Where {$_.HardDisks.StorageFormat -like "Thin"} | Move-VM -Datastore "iSCSIDatastore2" -DiskStorageFormat "Thick" 
Get-VM | Where {$_.HardDisks.StorageFormat -like "Thin" -and (Get-Datastore -RelatedObject $_) -notlike "iSCSIDatastore2"} | Move-VM -Datastore "iSCSIDatastore2" -DiskStorageFormat "Thick"
Get-VM | Where {$_.HardDisks.StorageFormat -like "Thin" -and (Get-Datastore -RelatedObject $_) -notlike "iSCSIDatastore1"} | Move-VM -Datastore "iSCSIDatastore1" -DiskStorageFormat "Thick"

<# Working with Datastore Clusters #> 
New-DatastoreCluster -Name "iSCSIcluster" -Location (Get-Datacenter Primary)
Get-Datastore -Name iSCSI*
Get-Datastore -Name iSCSI* | Move-Datastore -Destination (Get-DatastoreCluster -Name "iSCSICluster")
Set-DatastoreCluster -DatastoreCluster "iSCSICluster" -SdrsAutomationLevel FullyAutomated
Set-DatastoreCluster -DatastoreCluster "iSCSICluster" -SpaceUtilizationThresholdPercent 90
Set-DatastoreCluster -DatastoreCluster "iSCSICluster" -IoLatencyThresholdMillisecond 30 -IOLoadBalanceEnabled $True

<# Working with Datastore Cluster VM Settings #> 
$dsc = Get-DatastoreCluster "iSCSICluster"
$dsc | Select *
$dsc.ExtensionData
$dsc.ExtensionData.PodStorageDrsEntry.StorageDrsConfig
$storagemgr = Get-View StorageResourceManager
$spec = New-Object VMware.Vim.StorageDrsConfigSpec
$dsc.ExtensionData.PodStorageDrsEntry.StorageDrsConfig.VmConfig | Where {$_.VM -like "AD01*"}
$dsc.ExtensionData.PodStorageDrsEntry.StorageDrsConfig.VmConfig | Where {( Get-VM -Id $_.VM) -like "AD01*"}
$dsc.ExtensionData.PodStorageDrsEntry.StorageDrsConfig.VmConfig | Where {( Get-VM -Id $_.VM) -like "AD01*"} | ForEach {
    $vmconfig = New-Object VMware.Vim.StorageDrsVmConfigSpec
    $vmconfig.Operation = "edit"
    $vmconfig.Info = $_
    $vmconfig.Info.Enabled = $false
    $spec.vmConfigSpec += $vmconfig
}
$storagemgr.ConfigureStorageDrsForPod($dsc.ExtensionData.MoRef,$spec,$true)

<# #>
$dsc = Get-DatastoreCluster "iSCSICluster"
$dsc.ExtensionData.PodStorageDRSEntry
$dsc.ExtensionData.PodStorageDrsEntry.StorageDrsConfig
$storagemgr = Get-View StorageResourceManager
Get-VM -Name "AD01*"
Get-VM -Name "AD01*" | ForEach {
    $vmconfig = New-Object VMware.Vim.StorageDrsVmConfigSpec
    $vmconfig.Operation = "add"
    $info = New-Object VMware.Vim.StorageDrsVmConfigInfo
    $info.Vm = $_.Id
    $info.Enabled = $false
    $vmconfig.Info = $info
    $spec.vmConfigSpec += $vmconfig
}
$storagemgr.ConfigureStorageDrsForPod($dsc.ExtensionData.MoRef,$spec,$true)
