<# PowerCLI Cookbook - Chapter 5 Code #>

<# Import TTYLinux for use in this chapter #>
Import-vApp -Source C:\va\TTYLinux\TTYLinux.ovf -Name "TTYLinux1" -VMHost esxsrv1.domain.local

<# Creating a Snapshot #> 
New-Snapshot -VM TTYLinux1 -Name "My First Snapshot"
Get-VM -Name TTY* | New-Snapshot -Name "My Second Snapshot"
Get-VM -Name TTY* | New-Snapshot -Name "Before Maintenance" -Memory
Get-VM -Name TTY* | New-Snapshot -Name "After Maintenance" -Memory -Quiesce
Get-VM -Name TTY* | New-Snapshot -Name "After Installation" -Memory -Quiesce -Description "Requested by John in Accounting"

<# Getting list of snapshots in the environment #>
Get-VM | Get-Snapshot

<# Manipulating the list of snapshots to get better information #>  
Get-VM | Get-Snapshot | Select VM, Name, Description, PowerState
Get-VM -Name TTY* | Get-Snapshot | Select VM, Name, Description, PowerState
Get-VM | Get-Snapshot | Select VM, Name, Created
Get-VM | Get-Snapshot | Select VM, Name, SizeGB | Sort SizeGB -Desc

<# Scoping and filtering list of snapshots #>  
Get-VM | Get-Snapshot | Select VM, Name, Created, @{N="Size";E={"{0:N2} GB" -f ($_.SizeGB)}} 
Get-VM | Get-Snapshot | Select VM, Name, Created, @{N="Size";E={"{0:N2} GB" -f ($_.SizeGB)}} | Sort SizeGB -Desc 
Get-VM | Get-Snapshot | Where {$_.Created -LT "1/1/2014"}
(Get-Date).AddDays(-30)
Get-VM | Get-Snapshot | Where {$_.Created -LT (Get-Date).AddDays(-30)} | Select VM, Name, Created
Get-VM | Get-Snapshot | Where {$_.Created -LT (Get-Date).AddMinutes(-30)} | Select VM, Name, Created
Get-VM | Get-Snapshot | Where {$_.Created -LT (Get-Date).AddMinutes(-30) -AND $_.SizeGB -GT 5} | Select VM, Name, Created, @{N="Size";E={"{0:N2} GB" -f ($_.SizeGB)}}

<# Removing targeted snapshots #>
Get-Snapshot -VM TTYLinux1
Get-Snapshot -VM TTYLinux1 -Name "My Second Snapshot" | Remove-Snapshot
Get-Snapshot -VM TTYLinux1 | Remove-Snapshot -Confirm:$false
Get-Snapshot -VM * | Where {$_.Created -LT (Get-Date).AddDays(-30)} | Remove-Snapshot

<# Find lost or unknown snapshots #>
Get-VM | Get-HardDisk | Where {$_.Filename -like "*0000*"} | Select @{N="VM";E={$_.Parent}} | Get-Unique -AsString
Get-VM | Get-Snapshot | Select VM | Get-Unique -AsString
Compare-Object $(Get-VM | Get-HardDisk | Where {$_.Filename -like "*0000*"} | Select @{N="VM";E={$_.Parent}} | Get-Unique -AsString) $(Get-VM | Get-Snapshot | Select VM | Get-Unique -AsString) -Property VM 

$Targets = Compare-Object $(Get-VM | Get-HardDisk | Where {$_.Filename -like "*0000*"} | Select @{N="VM";E={$_.Parent}} | Get-Unique -AsString) $(Get-VM | Get-Snapshot | Select VM | Get-Unique -AsString) -Property VM
ForEach ($Target in $Targets) {
  New-Snapshot -Name "SnapRepair" -VM $targettTarget.VM
}
ForEach ($Target in $Targets) {
  Get-Snapshot -VM $Target.VM | Remove-Snapshot 
  -Confirm:$false
}

<# Scheduling automatic snapshot remediation #> 
Get-ExecutionPolicy
Set-ExecutionPolicy -ExecutionPolicy RemoteSigned
Set-AuthenticodeSignature C:\Scripts\Remove-30DaySnaps.ps1 @(Get-Children cert:\\CurrentUsers\My -codesigning)[0]
