<# Remove30DaySnaps.ps1  #> 
function Remove-30DaySnaps
{ 

<#
  .SYNOPSIS
  Removes any snapshots older than 30 days found on the targeted VMs as identified by the -VM parameter
  .DESCRIPTION
  Gets a list of snapshots that are older than 30 days for the list of VM that is provided into the function
  .EXAMPLE
  Remove30DaySnaps -VM * 
  .EXAMPLE
  Remove30DaySnaps -VM TestVM1 
  .PARAMETER VM
  The VM name to query.
  .PARAMETER DAYSOLD
  The number of days if the snapshot exceeds it is removed.
  #>

param (
  [Parameter(Mandatory=$True,
  ValueFromPipeline=$True,
  ValueFromPipelineByPropertyName=$True,
  HelpMessage='Name:')]
  [string[]]$VM, 
  [double]$DaysOld = 30
)

process {
  Get-Snapshot -VM $vm | Where {$_.Created -LT (Get-Date).AddDays(-$DaysOld)} | Remove-Snapshot -Confirm:$false
}

}
