<# PowerCLI Cookbook - Chapter 8 Code File #>

<# Working with ESXCLI #>
$esxcli = Get-VMHost esxsrv1.domain.local | Get-EsxCli 
$esxcli.vm
$esxcli.vm.process
$esxcli.vm.process.list()
$esxcli.vm.process.kill("soft", 1000397005)
$esxcli = Get-VMHost esxsrv1.domain.local | Get-EsxCli
$pingresults = $esxcli.network.diag.ping(1, $false, $false, "192.168.1.1", "vmk0", 1, $true, $false)
$pingresults.Summary
$pingresults[0].Summary

<# Using ESXCLI to configure storage rules

-- Original ESXCLI Commands to Replicate --

esxcli storage nmp satp rule add -s "VMW_SATP_SYMM" -V "EMC" -M "SYMMETRIX" -P "VMW_PSP_RR" -O "iops=1" -e "EMC Symmetrix (custom rule)"
esxcli storage nmp satp rule add -s "VMW_SATP_ALUA" -P "VMW_PSP_RR" -O iops=100 -c "tpgs_on" -V "3PARdata" -M "VV" -e "HP 3PAR Custom iSCSI/FC/FCoE ALUA Rule"

#> 
$esxcli = Get-VMHost esxsrv1.domain.local | Get-EsxCli
$esxcli.storage.nmp.satp.rule.add($null, $null, "EMC Symmetrix (custom rule)", $null, $null, $null, "SYMMETRIX", "iops=1", "VMW_PSP_RR", $null, "VMW_SATP_SYMM", $null, $null, "EMC")
$esxcli.storage.nmp.satp.rule.add($true, "tpgs_on", " HP 3PAR Custom iSCSI/FC/FCoE ALUA Rule", $null, $null, $null, "VV", "iops=100", "VMW_PSP_RR", $null, "VMW_SATP_ALUA", $null, $null, "3PARdata")

<# Set LUNS to Round Robin PSP #> 
Get-VMHost | Get-ScsiLun -CanonicalName "naa.600*" | Set-ScsiLun -MultipathPolicy "roundrobin"
$luns = $esxcli.storage.nmp.device.list()
ForEach ($lun in $luns) { 
  $esxcli.storage.nmp.device.set($null, $lun.Device, "VMW_PSP_RR")
} <# End ForEach #>
$esxcli.storage.nmp.psp.roundrobin.deviceconfig.set(0, 1, $lun.device, [long]100, "iops", $false)

<# Setting CoreDump Settings with ESXCLI in PowerCLI #>
$esxcli = Get-VMHost esxsrv1.domain.local | Get-EsxCli
$esxcli.system.coredump
$esxcli.system.coredump.network.get()
$esxcli.system.coredump.file.list()
boolean set(boolean enable, string interfacename, string serverip, string  serveripv4, long serverport)
$esxcli.system.coredump.network.set($null, "vmk0", $null, "192.168.1.200", "6500")
$esxcli.system.coredump.network.set($true)
boolean add(boolean auto, string datastore, boolean enable, string file, long size)
$esxcli.system.coredump.file.add($null,"DATASTORE1", $true, "CoreDumpFileName")
boolean set(boolean enable, string path, boolean smart, boolean unconfigure)
$esxcli.system.coredump.file.set($true, "/vmfs/volumes/53cabdf3-866f371f-c5bf-0017087d98f0/vmkdump/test.dumpfile")

<# Working with in guest scripting #> 
Get-Help Invoke-VMScript

$guestcreds = Get-Credential
Invoke-VMScript -ScriptText "echo Hello World" -VM "WinVM1" -GuestCredentials $guestcreds
$hostcreds = Get-Credential
Invoke-VMScript -ScriptText "echo Hello World" -VM "WinVM1" -GuestCredential $guestcreds -Server esxsrv1.domain.local -HostCredential $hostcreds
Invoke-VMScript -ScriptText "netsh winhttp show proxy" -VM "WinVM1" -GuestCredentials $guestcreds
 
$linuxcreds = Get-Credential
Invoke-VMScript -ScriptText "service apache2 stop" -VM Ubuntu14 -GuestCredential $linuxcreds
Invoke-VMScript -ScriptText "service apache2 start" -VM Ubuntu14 -GuestCredential $linuxcreds
 
