<# PowerCLI Cookbook - Chapter 10 Code File #> 

<# Connecting to a vCloud environment #> 
Connect-CiServer vcloud.lab.local
$DefaultCiServers | Select *

<# Creating and managing organizations in vCloud #> 
Connect-CiServer vcloud.lab.local
New-Org -Name Red -FullName "Red Org"
New-Org -Name Blue -FullName "Blue Org"
New-Org -Name Orange -FullName "Orange Org"

<# Creating a new user in an organization using Views #>
<# Import or execute CIUser.ps1 in same directory #>
New-CIUser -Name "orange1" -Password "newpass"  -FullName "Orange Admin" -Org "Orange" -Role "Organization Administrator"
Connect-CIServer vcloud.lab.local -Org Orange
 
<# Creating an organization's virtual data center in vCloud Director #>
$Org = Get-Org -Name "Orange"
$ProviderVDC = Get-ProviderVdc -Name "PrimaryVDC"
New-OrgVDC -Name "Orange OnSite DC" -Org $Org -ProviderVdc $ProviderVDC -AllocationModelAllocationPool 
New-OrgVDC -Name "Blue OnSite DC" -Org (Get-Org "Blue") -ProviderVdc (Get-ProvidedVdc -Name "PrimaryVDC") -AllocationModeAllocationPool
Get-OrgVDC -Name "Orange Onsite DC" | Set-OrgVDC -UseFastProvisioning $true

<# Importing a vApp Template into vCloud #>
Connect-CIServer vcloud.lab.local
Connect-VIServer vcenter.lab.local
Import-CIvApp -VM (Get-VM "TTYLinux1") -Name TTYLinux-vApp -OrgVDC (Get-OrgVDC -Name "Orange Onsite DC")

<# Configuring networking in a vCloud vApp #>
Get-OrgNetwork -Org "Orange"
$ExtNet = Get-ExternalNetwork "Local"
$OrgVdcNetwork = New-Object VMware.VimAutomation.Cloud.Views.OrgVdcNetwork
$orgVdcNetwork.Name = "Orange External Network"
$orgVdcNetwork.IsShared = $false
$orgVdcNetwork.Configuration = New-Object VMware.VimAutomation.Cloud.Views.NetworkConfiguration
$orgVdcNetwork.Configuration.ParentNetwork = $ExtNet.href 
$orgVdcNetwork.Configuration.FenceMode = 'bridged' 
$orgVdcNetwork.Configuration.IpScopes = New-Object VMware.VimAutomation.Cloud.Views.IpScopes
$orgVdcNetwork.Configuration.IpScopes.IpScope += $ExtNet.ExtensionData.Configuration.IpScopes.IpScope
$orgVdcView = (Get-OrgVdc -name "Orange Onsite DC").ExtensionData
$orgVdcView.CreateNetwork($orgVdcNetwork)
New-CIVAppNetwork -VApp (Get-CIVapp -Name "TTYLinux-vApp") -Direct -ParentOrgNetwork (Get-OrgNetwork -Name "Orange External Network")

<# Reassigning vApp VM network settings with PowerCLI #>
Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVAppNetwork
$IsolatedNet = Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVAppNetwork -ConnectionType Isolated
$DirectNet = Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVAppNetwork -ConnectionType Direct
Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVM | Get-CINetworkAdapter | Set-CINetworkAdapter -VAppNetwork $DirectNet -Connected $true -IpAddressAllocationMode "Dhcp"
Remove-CIVAppNetwork -vAppNetwork $IsolatedNet

<# Reassigning vApp VM network settings with PowerCLI #>
Get-CIVApp -Name "TTYLinux-vApp" | Start-CIVApp
Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVM | Restart-CIVM
Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVM | Stop-CIVM
Get-CIVApp -Name "TTYLinux-vApp" | Get-CIVM | Start-CIVM
Get-CIVApp -Name "TTYLinux-vApp" | Stop-CIVApp
Get-CIVApp -Name "TTYLinux-vApp" | Remove-CIVApp
