Function New-CIUser { 
<#
.SYNOPSIS
  Creates a new user in a vCloud installation
.DESCRIPTION
  Creates a new user account in an organization of a vCloud Director installation
.PARAMETER Name
  The username of the new user
.PARAMETER FullName
  The full name or display name of the user
.PARAMETER Password
  The password for the new user account
.PARAMETER Org
  The name of the organization to add the user into
.PARAMETER Role
  The role of the new user to be defined for the organization
.EXAMPLE
  New-CIUser -Name newuser -Password newpass -Org OrgName -FullName "First Last" -Role "Organization Administrator"
#> 
Param ( 
   $Name, 
   $Password, 
   $FullName, 
   $Org, 
$Role 
) 
Process {
    $orgAdminUser = New-Object VMware.VimAutomation.Cloud.Views.User 
    $orgAdminUser.Name = $Name 
    $orgAdminUser.FullName = $FullName 
    $orgAdminUser.Password = $Password 
    $orgAdminUser.IsEnabled = $true
    Switch ($Role.GetType().Name ) {
      "Reference" { $orgAdminUser.Role = $Role }
      "String" { 
          $vcloud = $DefaultCIServers[0].ExtensionData 
          $orgAdminRole = $vcloud.RoleReferences.RoleReference | Where {$_.Name -eq $Role} 
        $orgAdminUser.Role = $orgAdminRole 
      }
    }    
    $OrgED = (Get-Org $Org).ExtensionData 
    $user = $OrgED.CreateUser($orgAdminUser) 
    Get-CIUser -Org $Org -Name $Name
}
}